MemoryKvStore

Struct MemoryKvStore 

pub struct MemoryKvStore { /* private fields */ }
A Backend for the graph database running in memory only.

Use this for testing purposes or if your data does not need to be persisted permanently.

Implementations